==> longpress_popup-1.5.1.tar.gz: example/lib/example_popup_with_data.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_map/flutter_map.dart';
import 'package:longpress_popup/fluttermap_markerpopup.dart';
import 'package:latlong2/latlong.dart';

void main() => runApp(const MyApp());

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return const MaterialApp(
      title: 'Marker with additional data example',
      home: MapPage(),
    );
  }
}

class MapPage extends StatefulWidget {
  const MapPage({Key? key}) : super(key: key);

  @override
  State<MapPage> createState() => _MapPageState();
}

class DataMarker extends MarkerData {
  Marker mark;

  DataMarker(this.mark) : super(marker: mark);
}

class _MapPageState extends State<MapPage> {
  final PopupController _popupLayerController = PopupController();

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: FlutterMap(
        options: MapOptions(
          center: LatLng(48.857661, 2.295135),
          zoom: 13.0,
          interactiveFlags: InteractiveFlag.all,
          onTap: (_, __) => _popupLayerController.hideAllPopups(),
        ),
        children: <Widget>[
          TileLayerWidget(
            options: TileLayerOptions(
              urlTemplate: 'https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png',
              subdomains: <String>['a', 'b', 'c'],
            ),
          ),
          PopupMarkerLayerWidget(
            options: PopupMarkerLayerOptions(
              markersData: <MarkerData>[
                DataMarker(MonumentMarker(
                  monument: Monument(
                    name: 'Eiffel Tower',
                    imagePath:
                        'https://cdn.lifestyleasia.com/wp-content/uploads/2019/10/21224220/Winer-Parisienne.jpg',
                    lat: 48.857661,
                    long: 2.295135,
                  ),
                )),
                DataMarker(Marker(
                  anchorPos: AnchorPos.align(AnchorAlign.top),
                  point: LatLng(48.859661, 2.305135),
                  height: Monument.size,
                  width: Monument.size,
                  builder: (BuildContext ctx) => const Icon(Icons.shop),
                )),
              ],
              popupController: _popupLayerController,
              popupBuilder: (_, MarkerData marker) {
                var marker2 = marker.marker;
                if (marker2 is MonumentMarker) {
                  return MonumentMarkerPopup(monument: marker2.monument);
                }
                return const Card(child: Text('Not a monument'));
              },
            ),
          ),
        ],
      ),
    );
  }
}

class Monument {
  static const double size = 25;

  Monument({
    required this.name,
    required this.imagePath,
    required this.lat,
    required this.long,
  });

  final String name;
  final String imagePath;
  final double lat;
  final double long;
}

class MonumentMarker extends Marker {
  MonumentMarker({required this.monument})
      : super(
          anchorPos: AnchorPos.align(AnchorAlign.top),
          height: Monument.size,
          width: Monument.size,
          point: LatLng(monument.lat, monument.long),
          builder: (BuildContext ctx) => const Icon(Icons.camera_alt),
        );

  final Monument monument;
}

class MonumentMarkerPopup extends StatelessWidget {
  const MonumentMarkerPopup({Key? key, required this.monument}) : super(key: key);
  final Monument monument;

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      width: 200,
      child: Card(
        shape: RoundedRectangleBorder(
          borderRadius: BorderRadius.circular(15),
        ),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            Image.network(monument.imagePath, width: 200),
            Text(monument.name),
            Text('${monument.lat}-${monument.long}'),
          ],
        ),
      ),
    );
  }
}

==> longpress_popup-1.5.4.tar.gz: example/lib/example_popup_with_data.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_map/flutter_map.dart';
import 'package:longpress_popup/fluttermap_markerpopup.dart';
import 'package:latlong2/latlong.dart';

void main() => runApp(const MyApp());

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return const MaterialApp(
      title: 'Marker with additional data example',
      home: MapPage(),
    );
  }
}

class MapPage extends StatefulWidget {
  const MapPage({Key? key}) : super(key: key);

  @override
  State<MapPage> createState() => _MapPageState();
}

class DataMarker extends MarkerData {
  Marker mark;

  DataMarker(this.mark) : super(marker: mark);
}

class _MapPageState extends State<MapPage> {
  final PopupController _popupLayerController = PopupController();

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: FlutterMap(
        options: MapOptions(
          center: LatLng(48.857661, 2.295135),
          zoom: 13.0,
          interactiveFlags: InteractiveFlag.all,
          onTap: (_, __) => _popupLayerController.hideAllPopups(),
        ),
        children: <Widget>[
          TileLayerWidget(
            options: TileLayerOptions(
              urlTemplate: 'https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png',
              subdomains: <String>['a', 'b', 'c'],
            ),
          ),
          PopupMarkerLayerWidget(
            options: PopupMarkerLayerOptions(
              markersData: <MarkerData>[
                DataMarker(MonumentMarker(
                  monument: Monument(
                    name: 'Eiffel Tower',
                    imagePath:
                        'https://cdn.lifestyleasia.com/wp-content/uploads/2019/10/21224220/Winer-Parisienne.jpg',
                    lat: 48.857661,
                    long: 2.295135,
                  ),
                )),
                DataMarker(Marker(
                  anchorPos: AnchorPos.align(AnchorAlign.top),
                  point: LatLng(48.859661, 2.305135),
                  height: Monument.size,
                  width: Monument.size,
                  builder: (BuildContext ctx) => const Icon(Icons.shop),
                )),
              ],
              popupController: _popupLayerController,
              popupBuilder: (_, MarkerData marker) {
                var marker2 = marker.marker;
                if (marker2 is MonumentMarker) {
                  return MonumentMarkerPopup(monument: marker2.monument);
                }
                return const Card(child: Text('Not a monument'));
              },
            ),
          ),
        ],
      ),
    );
  }
}

class Monument {
  static const double size = 25;

  Monument({
    required this.name,
    required this.imagePath,
    required this.lat,
    required this.long,
  });

  final String name;
  final String imagePath;
  final double lat;
  final double long;
}

class MonumentMarker extends Marker {
  MonumentMarker({required this.monument})
      : super(
          anchorPos: AnchorPos.align(AnchorAlign.top),
          height: Monument.size,
          width: Monument.size,
          point: LatLng(monument.lat, monument.long),
          builder: (BuildContext ctx) => const Icon(Icons.camera_alt),
        );

  final Monument monument;
}

class MonumentMarkerPopup extends StatelessWidget {
  const MonumentMarkerPopup({Key? key, required this.monument})
      : super(key: key);
  final Monument monument;

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      width: 200,
      child: Card(
        shape: RoundedRectangleBorder(
          borderRadius: BorderRadius.circular(15),
        ),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          children: <Widget>[
            Image.network(monument.imagePath, width: 200),
            Text(monument.name),
            Text('${monument.lat}-${monument.long}'),
          ],
        ),
      ),
    );
  }
}
